@@ -190,7 +190,8 @@ mssm <- function(
       covar_fac = control$covar_fac, ftol_rel = control$ftol_rel,
       N_part = N_part, what = what,
       which_sampler = control$which_sampler, which_ll_cp = control$which_ll_cp,
-      trace, KD_N_max = control$KD_N_max, aprx_eps = control$aprx_eps)
+      trace, KD_N_max = control$KD_N_max, aprx_eps = control$aprx_eps,
+      use_antithetic = control$use_antithetic)
 
     # set dimension names
     di <- .get_dimnames(output_list)
@@ -264,7 +265,8 @@ mssm <- function(
       covar_fac = control$covar_fac, ftol_rel = control$ftol_rel,
       N_part = object$N_part, what = "log_density", trace = 0L,
       KD_N_max = control$KD_N_max, aprx_eps = control$aprx_eps,
-      which_ll_cp = control$which_ll_cp, pf_output = object$pf_output)
+      which_ll_cp = control$which_ll_cp, pf_output = object$pf_output,
+      use_antithetic = control$use_antithetic)
 
     out <- mapply(
       function(x, y) c(y, list(ws_normalized_smooth = x)),
@@ -530,6 +532,8 @@ NULL
 #' approximation. The \code{_inner} denotes the values passed in the inner
 #' mode estimation. The mode estimation is done with a custom Newton–Raphson
 #' method
+#' @param use_antithetic logical which is true if antithetic variables should
+#' be used.
 #'
 #' @seealso
 #' \code{\link{mssm}}.
@@ -547,7 +551,7 @@ mssm_control <- function(
   what = "log_density", which_sampler = "mode_aprx", which_ll_cp = "no_aprx",
   seed = 1L, KD_N_max = 10L, aprx_eps = 1e-3, ftol_abs = 1e-4,
   ftol_abs_inner = 1e-4, la_ftol_rel = -1., la_ftol_rel_inner = -1.,
-  maxeval = 10000L, maxeval_inner = 10000L){
+  maxeval = 10000L, maxeval_inner = 10000L, use_antithetic = FALSE){
   stopifnot(
     .is.num.le1(n_threads), n_threads > 0L,
     .is.num.le1(covar_fac), covar_fac > 0.,
@@ -571,17 +575,22 @@ mssm_control <- function(
     ftol_abs_inner > 0. || la_ftol_rel_inner > 0.,
 
     .is.int.le1(maxeval), maxeval > 0L,
-    .is.int.le1(maxeval_inner), maxeval_inner > 0L)
+    .is.int.le1(maxeval_inner), maxeval_inner > 0L,
+    length(use_antithetic) == 1L, is.logical(use_antithetic))
   .is_valid_N_part(N_part)
   .is_valid_what(what)
 
+  if(use_antithetic && nu <= 2.)
+    stop("Antithetic variables not implemented with normal distribution")
+
   list(
     N_part = N_part, n_threads = n_threads, covar_fac = covar_fac,
     ftol_rel = ftol_rel, what = what, which_sampler = which_sampler,
     which_ll_cp = which_ll_cp, nu = nu, seed = seed, KD_N_max = KD_N_max,
     aprx_eps = aprx_eps, ftol_abs = ftol_abs, la_ftol_rel = la_ftol_rel,
     ftol_abs_inner = ftol_abs_inner, la_ftol_rel_inner = la_ftol_rel_inner,
-    maxeval = maxeval, maxeval_inner = maxeval_inner)
+    maxeval = maxeval, maxeval_inner = maxeval_inner,
+    use_antithetic = use_antithetic)
 }
 
 .is_valid_N_part <- function(N_part)
