@@ -2,14 +2,16 @@
 
 extern "C" {
   void F77_NAME(dgetrf)
-    (const int *m, const int *n, double *a, const int *lda,
-     int *ipiv, int *info);
-
+    (const int* m, const int* n, double* a, const int* lda,
+     int* ipiv, int* info);
   void F77_NAME(dpbtrf)
     (const char* uplo, const int* n, const int* kd,
-     double* ab, const int* ldab, int* info);
+     double* ab, const int* ldab, int* info,
+     size_t);
   void F77_NAME(dpotri)
-    (char *uplo, int *n, double *a, int *lda, int *info);
+    (const char* uplo, const int* n,
+     double* a, const int* lda, int* info,
+     size_t);
 }
 
 namespace lapack {
@@ -22,12 +24,12 @@ namespace lapack {
   void dpbtrf
   (const char* uplo, const int* n, const int* kd,
    double* ab, const int* ldab, int* info){
-    F77_CALL(::dpbtrf)(uplo, n, kd, ab, ldab, info);
+    F77_CALL(::dpbtrf)(uplo, n, kd, ab, ldab, info, 1);
   }
 
   void dpotri
     (char* uplo, int *n, double *a, int *lda, int *info){
-    F77_CALL(::dpotri)(uplo, n, a, lda, info);
+    F77_CALL(::dpotri)(uplo, n, a, lda, info, 1);
   }
 }
 
